@@ -34,10 +34,10 @@
 using namespace SendLater;
 
 SendLaterDialog::SendLaterDialog(SendLater::SendLaterInfo *info, QWidget *parent)
-    : QDialog(parent),
-      mAction(Unknown),
-      mDelay(nullptr),
-      mInfo(info)
+    : QDialog(parent)
+    , mAction(Unknown)
+    , mDelay(nullptr)
+    , mInfo(info)
 {
     setWindowTitle(i18nc("@title:window", "Send Later"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
@@ -159,4 +159,3 @@ void SendLaterDialog::slotDelay(bool delayEnabled)
     mSendLaterWidget->mRecurrenceValue->setEnabled(delayEnabled && mSendLaterWidget->mRecurrence->isChecked());
     mSendLaterWidget->mRecurrenceComboBox->setEnabled(delayEnabled && mSendLaterWidget->mRecurrence->isChecked());
 }
-
